TextDescriptives
================================

.. image:: https://img.shields.io/github/stars/hlasse/textdescriptives.svg?style=social&label=Star&maxAge=2592000
   :target: https://github.com/hlasse/textdescriptives

TextDescriptives is Python library for calculating a large variety of statistics from text(s) using spaCy v.3 pipeline components and extensions. 
TextDescriptives can be used to calculate several descriptive statistics, readability metrics, and metrics related to dependency distance. 
If you wish to try out the package, you can use the `online demo <https://huggingface.co/spaces/HLasse/textdescriptives>`__.
  
The documentation is organized in two parts:

- **Getting Started** contains the installation instructions, guides, and tutorials on how to use the package.
- **Package References** contains the documentation of each public class and function.


Where to ask questions?
^^^^^^^^^^^^^^^^^^^^^^^^

To ask report issues or request features, please use the
`GitHub Issue Tracker <https://github.com/HLasse/TextDescriptives/issues>`__.
Questions related to SpaCy are kindly referred to the SpaCy GitHub or forum. Otherwise,
please use the discussion Forums.

+------------------------------+-------------------------+
| Type                         |                         |
+------------------------------+-------------------------+
| **Bug Reports**              | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Feature Requests & Ideas** | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Usage Questions**          | `GitHub Discussions`_   |
+------------------------------+-------------------------+
| **General Discussion**       | `GitHub Discussions`_   |
+------------------------------+-------------------------+


Citation
^^^^^^^^^^^^^^^^^^^^^^^^
If you use TextDescriptives in your research, please cite the following preprint:
`TextDescriptives: A Python package for calculating a large variety of statistics from text <https://arxiv.org/abs/2301.02057>`__.



.. _GitHub Issue Tracker: https://github.com/HLasse/TextDescriptives/issues
.. _GitHub Discussions: https://github.com/HLasse/TextDescriptives/discussions

.. toctree::
   :maxdepth: 1
   :caption: Getting Started
   :hidden:

   installation
   usingthepackage
   tutorial
   news
   faq

.. toctree::
   :maxdepth: 2
   :caption: Components
   :hidden:

   descriptivestats
   readability
   dependencydistance
   posstats
   quality
   coherence
   information_theory
   extractors


.. toctree::
   :hidden:
   
   GitHub Repository <https://github.com/hlasse/TextDescriptives>

   

Indices and search
==================

* :ref:`genindex`
* :ref:`search`
